==> shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05.tar.gz: shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05/shinken/shinken/objects/module.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2009-2012:
#    Gabes Jean, naparuba@gmail.com
#    Gerhard Lausser, Gerhard.Lausser@consol.de
#    Gregory Starck, g.starck@gmail.com
#    Hartmut Goebel, h.goebel@goebel-consult.de
#
# This file is part of Shinken.
#
# Shinken is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Shinken is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Shinken.  If not, see <http://www.gnu.org/licenses/>.

import hashlib

from item import Item, Items
from shinken.log import logger
from shinken.misc.type_hint import TYPE_CHECKING
from shinken.property import StringProp, ListProp
from shinken.util import strip_and_uniq

if TYPE_CHECKING:
    from shinken.misc.type_hint import Any, Callable, List, Optional, Set


class Module(Item):
    id = 1  # zero is always special in database, so we do not take risk here
    my_type = 'module'
    
    properties = Item.properties.copy()
    properties.update({
        'module_name': StringProp(),
        'module_type': StringProp(),
        'modules'    : ListProp(default=''),
    })
    
    running_properties = Item.running_properties.copy()
    running_properties.update({
        'configuration_default_value': StringProp(default={}),
    })
    
    macros = {}
    
    
    def __init__(self, params=None, skip_useless_in_configuration=False):
        self.module_type = ''
        if params is None:
            params = {}
        super(Module, self).__init__(params=params)
        self.configuration_properties = set(params.keys())
    
    
    def __compute_hash(self):
        hash_ = hashlib.md5()  # don't bother me about blabla md5 secutiry blabla. We don't care here baka
        keys = list(self.configuration_properties)
        keys.sort()
        for k in keys:
            hash_.update(k)
            value = getattr(self, k, '')
            if isinstance(value, basestring):
                hash_.update(value.encode('ascii', 'ignore'))
            else:  # maybe it's a list due to set the key multiple times.
                hash_.update(str(value))
        self.hash = hash_.hexdigest()
    
    
    def set_some_properties(self, properties):
        # type: (List[Set[basestring, Any, Optional[Callable]]]) -> None
        for property_name, property_value, value_convert in properties:
            if value_convert:
                try:
                    property_value = value_convert(property_value)
                except ValueError:
                    pass
            setattr(self, property_name, property_value)
            self.configuration_properties.add(property_name)
        self.__compute_hash()
    
    
    def set_father_config(self, config):
        self.father_config = config
    
    
    def get_name(self):
        return getattr(self, 'module_name', 'unnamed')
    
    
    def get_type(self):
        return getattr(self, 'module_type', '')
    
    
    # For debugging purpose only (nice name)
    def get_modules(self):
        return self.modules


class Modules(Items):
    name_property = "module_name"
    inner_class = Module
    
    
    def fill_running_properties(self, config):
        for module in self:
            module.set_some_properties([(u'properties_display_text', getattr(config, u'properties_display_text'), None),
                                        (u'configuration_default_value', config.default_properties_values, None),
                                        (u'minimal_time_before_an_element_become_missing_data', config.minimal_time_before_an_element_become_missing_data, int),
                                        (u'minimal_time_before_an_element_become_missing_data_at_startup', config.minimal_time_before_an_element_become_missing_data_at_startup, int),
                                        (u'modules_dir', config.modules_dir, None)])
    
    
    def linkify(self):
        self.linkify_s_by_plug()
    
    
    def linkify_s_by_plug(self):
        for s in self:
            new_modules = []
            mods = s.modules.split(',')
            mods = strip_and_uniq(mods)
            for plug_name in mods:
                plug_name = plug_name.strip()
                
                # don't read void names
                if plug_name == '':
                    continue
                
                # We are the modules, we search them :)
                plug = self.find_by_name(plug_name)
                if plug is not None:
                    new_modules.append(plug)
                else:
                    err = "[module] unknown %s module from %s" % (plug_name, s.get_name())
                    logger.error(err)
                    s.configuration_errors.append(err)
            
            s.modules = new_modules
            # We need to update the module hash with the ones from the new modules, because if one
            # submodule change, we should change too
            modules_sorted = sorted(s.modules, key=lambda x: x.get_name())
            hash_compute = hashlib.md5(s.hash)  # start with the current hash as param and not value, but will do the trick
            for m in modules_sorted:
                hash_compute.update(m.hash)
            s.hash = hash_compute.hexdigest()
    
    
    def explode(self):
        pass

==> shinken-enterprise_V02.08.01.07_ALL-LANG_Windows-poller-only_FULL_2023-10-03.tar.gz: shinken-enterprise_V02.08.01.07_ALL-LANG_Windows-poller-only_FULL_2023-10-03/shinken/shinken/objects/module.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2009-2012:
#    Gabes Jean, naparuba@gmail.com
#    Gerhard Lausser, Gerhard.Lausser@consol.de
#    Gregory Starck, g.starck@gmail.com
#    Hartmut Goebel, h.goebel@goebel-consult.de
#
# This file is part of Shinken.
#
# Shinken is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Shinken is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Shinken.  If not, see <http://www.gnu.org/licenses/>.

import hashlib

from item import Item, Items
from shinken.log import logger
from shinken.misc.type_hint import TYPE_CHECKING
from shinken.property import StringProp, ListProp
from shinken.util import strip_and_uniq
from shinkensolutions.lib_modules.configuration_reader_mixin import ConfigurationReader

if TYPE_CHECKING:
    from shinken.misc.type_hint import Any, Callable, List, Optional, Tuple


class Module(Item):
    id = 1  # zero is always special in database, so we do not take risk here
    my_type = 'module'
    
    if TYPE_CHECKING:
        module_name = None  # type: Optional[unicode]
        module_type = None  # type: Optional[unicode]
        modules = None  # type: Optional[List]
    
    properties = Item.properties.copy()
    properties.update({
        'module_name': StringProp(),
        'module_type': StringProp(),
        'modules'    : ListProp(default=''),
    })
    
    running_properties = Item.running_properties.copy()
    running_properties.update({
        'configuration_default_value': StringProp(default={}),
    })
    
    macros = {}
    
    
    def __init__(self, params=None, skip_useless_in_configuration=False):
        self.module_type = ''
        if params is None:
            params = {}
        super(Module, self).__init__(params=params)
        self.configuration_properties = set(params.keys())
    
    
    def __compute_hash(self):
        hash_ = hashlib.md5()  # don't bother me about blabla md5 security blabla. We don't care here baka
        keys = list(self.configuration_properties)
        keys.sort()
        for k in keys:
            hash_.update(k)
            value = getattr(self, k, '')
            if isinstance(value, basestring):
                hash_.update(value.encode('ascii', 'ignore'))
            else:  # maybe it's a list due to set the key multiple times.
                hash_.update(str(value))
        self.hash = hash_.hexdigest()
    
    
    def set_some_properties(self, properties):
        # type: (List[Tuple[unicode, Any, Optional[Callable]]]) -> None
        for property_name, property_value, value_convert in properties:
            if value_convert:
                try:
                    property_value = value_convert(property_value)
                except ValueError:
                    pass
            setattr(self, property_name, property_value)
            self.configuration_properties.add(property_name)
        self.__compute_hash()
    
    
    def set_father_config(self, config):
        self.father_config = config
    
    
    def get_name(self):
        return getattr(self, 'module_name', 'unnamed')
    
    
    def get_type(self):
        return getattr(self, 'module_type', '')
    
    
    # For debugging purpose only (nice name)
    def get_modules(self):
        return self.modules


class Modules(Items):
    name_property = "module_name"
    inner_class = Module
    
    
    def fill_running_properties(self, config):
        for module in self:
            module.set_some_properties([(u'properties_display_text', getattr(config, u'properties_display_text'), None),
                                        (u'configuration_default_value', config.default_properties_values, None),
                                        (u'minimal_time_before_an_element_become_missing_data', config.minimal_time_before_an_element_become_missing_data, int),
                                        (u'minimal_time_before_an_element_become_missing_data_at_startup', config.minimal_time_before_an_element_become_missing_data_at_startup, int),
                                        (u'modules_dir', config.modules_dir, None)])
    
    
    def linkify(self):
        self.linkify_s_by_plug()
    
    
    def linkify_s_by_plug(self):
        for s in self:
            new_modules = []
            mods = s.modules.split(',')
            mods = strip_and_uniq(mods)
            for plug_name in mods:
                plug_name = plug_name.strip()
                
                # don't read void names
                if plug_name == '':
                    continue
                
                # We are the modules, we search them :)
                plug = self.find_by_name(plug_name)
                if plug is not None:
                    new_modules.append(plug)
                else:
                    err = "[module] unknown %s module from %s" % (plug_name, s.get_name())
                    logger.error(err)
                    s.configuration_errors.append(err)
            
            s.modules = new_modules
            # We need to update the module hash with the ones from the new modules, because if one
            # submodule change, we should change too
            modules_sorted = sorted(s.modules, key=lambda x: x.get_name())
            hash_compute = hashlib.md5(s.hash)  # start with the current hash as param and not value, but will do the trick
            for m in modules_sorted:
                hash_compute.update(m.hash)
            s.hash = hash_compute.hexdigest()
    
    
    def explode(self):
        pass
    
    
    def update_with_module_info(self, modules_dir):
        ConfigurationReader.update_all_modules_with_module_info(modules_dir, self)
